local cjson = require "cjson.safe"
local redis = require "resty.redis"

local _M = {}

function _M.handle_api_request(api_key)
    if api_key ~= os.getenv("JASIMA_API_KEY") then
        ngx.exit(401)
    end
    if ngx.var.request_uri == "/update" then
        ngx.req.read_body()
        local body_data = ngx.req.get_body_data()
        if not body_data then
            ngx.status = 400
            ngx.say("No request body")
            ngx.exit(400)
        end
        local config = cjson.decode(body_data)

        local red = redis:new()
        red:set_timeout(1000)
        red:set_keepalive(10000, 100)

        local ok, err = red:connect("redis", 6379)
        if not ok then return nil, "Redis connect failed: " .. err end

        for jasima_key, rewrite_config in pairs(config.origins) do
            local key = "jasima:config:" .. jasima_key
            red:set(key, cjson.encode(rewrite_config))
        end

        for pool, poolmap in pairs(config.pools) do
            local key = "jasima:poolmap:" .. pool
            red:set(key, cjson.encode(poolmap))
        end

        if not config.pools.public then
            -- This is a default and things break if we don't have it
            red:set("jasima:poolmap:public", "{}")
        end

        ngx.exit(200)
    end
    ngx.exit(404)
end

return _M
